@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Any, List, Optional, Sequence, Set
+from typing import List, Optional, Sequence, Set
 
 import blacksmith
 from blacksmith.domain.registry import HttpResource, registry
@@ -16,7 +16,9 @@ sd = blacksmith.SyncRouterDiscovery(
     unversioned_service_url_fmt="http://{service}.NaN",
 )
 
-cli: blacksmith.SyncClientFactory[Any, Any] = blacksmith.SyncClientFactory(sd=sd)
+cli: blacksmith.SyncClientFactory[blacksmith.HTTPError] = blacksmith.SyncClientFactory(
+    sd=sd
+)
 
 
 class ResponseModel(BaseModel):
